lcvtoolbox.vision.geometry.primitives.transformation\_matrix.RotationVector
===========================================================================

.. currentmodule:: lcvtoolbox.vision.geometry.primitives.transformation_matrix

.. autoclass:: RotationVector
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :special-members: __init__, __str__, __repr__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~RotationVector.__init__
      ~RotationVector.apply_to_vector
      ~RotationVector.compose
      ~RotationVector.copy
      ~RotationVector.distance_to
      ~RotationVector.from_axis_angle
      ~RotationVector.from_quaternion
      ~RotationVector.from_rotation_matrix
      ~RotationVector.from_rpy
      ~RotationVector.identity
      ~RotationVector.interpolate
      ~RotationVector.inverse
      ~RotationVector.is_close
      ~RotationVector.normalize_angle
      ~RotationVector.power
      ~RotationVector.random
      ~RotationVector.to_axis_angle
      ~RotationVector.to_quaternion
      ~RotationVector.to_rotation_matrix
      ~RotationVector.to_rpy
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~RotationVector.angle
      ~RotationVector.axis
      ~RotationVector.numpy
      ~RotationVector.vector
   
   